==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/StepAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { StepAreaSeriesDescription } from "./StepAreaSeriesDescription";
/**
 * @hidden
 */
var StepAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StepAreaSeriesDescriptionMetadata, _super);
    function StepAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StepAreaSeriesDescriptionMetadata.b = function (a) {
        if (StepAreaSeriesDescriptionMetadata.a == null) {
            StepAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StepAreaSeriesDescriptionMetadata.c(StepAreaSeriesDescriptionMetadata.a);
        }
        if (a.j(StepAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(StepAreaSeriesDescriptionMetadata.a);
    };
    StepAreaSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
    };
    StepAreaSeriesDescriptionMetadata.d = function (a) {
        StepAreaSeriesDescriptionMetadata.b(a);
        a.aa("StepAreaSeries", function () { return new StepAreaSeriesDescription(); });
        a.z("StepAreaSeries", StepAreaSeriesDescriptionMetadata.a);
    };
    StepAreaSeriesDescriptionMetadata.$t = markType(StepAreaSeriesDescriptionMetadata, 'StepAreaSeriesDescriptionMetadata');
    StepAreaSeriesDescriptionMetadata.a = null;
    return StepAreaSeriesDescriptionMetadata;
}(Base));
export { StepAreaSeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/StepAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { StepAreaSeriesDescription } from "./StepAreaSeriesDescription";
/**
 * @hidden
 */
var StepAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StepAreaSeriesDescriptionMetadata, _super);
    function StepAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StepAreaSeriesDescriptionMetadata.b = function (a) {
        if (StepAreaSeriesDescriptionMetadata.a == null) {
            StepAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StepAreaSeriesDescriptionMetadata.c(StepAreaSeriesDescriptionMetadata.a);
        }
        if (a.k(StepAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(StepAreaSeriesDescriptionMetadata.a);
    };
    StepAreaSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
    };
    StepAreaSeriesDescriptionMetadata.d = function (a) {
        StepAreaSeriesDescriptionMetadata.b(a);
        a.ac("StepAreaSeries", function () { return new StepAreaSeriesDescription(); });
        a.ab("StepAreaSeries", StepAreaSeriesDescriptionMetadata.a);
    };
    StepAreaSeriesDescriptionMetadata.$t = markType(StepAreaSeriesDescriptionMetadata, 'StepAreaSeriesDescriptionMetadata');
    StepAreaSeriesDescriptionMetadata.a = null;
    return StepAreaSeriesDescriptionMetadata;
}(Base));
export { StepAreaSeriesDescriptionMetadata };
